@@ -32,7 +32,8 @@ class PhLogs(object):
         formatter = logging.Formatter("{ 'Time': %(asctime)s, 'Message': %(message)s, 'File': %(filename)s, 'Func': "
                                       "%(funcName)s, 'Line': %(lineno)s, 'Level': %(levelname)s } ")
 
-        sys_handler = logging.StreamHandler(stream=sys.stdout)
+        sys_handler = logging.StreamHandler(stream=sys.stdout).FileHandler(encoding='utf-8')
+
         sys_handler.setFormatter(formatter)
         for handler in self.logger.handlers:
             self.logger.removeHandler(handler)
