@@ -14,6 +14,36 @@ class PhRTPython3(PhRTBase):
     def __init__(self, **kwargs):
         self.__dict__.update(kwargs)
 
+    def put_items2dy(self, config):
+        table_name = "dagconf"
+        config.load_yaml()
+        inputs = {}
+        outputs = {}
+        for input in config.spec.containers.args:
+            inputs.update({input.key: input.value})
+        for output in config.spec.containers.outputs:
+            outputs.update({output.key: output.value})
+
+        timeout = config.spec.containers.timeout
+        runtime = config.spec.containers.runtime
+        labels = config.metadata.labels
+
+
+        print(type(timeout))
+        print(type(runtime))
+        print(type(labels))
+        data={}
+        data.update({"project_Id": "max"})
+        data.update({"flow_version": "developer2"})
+        data.update({"job_name": self.name})
+        data.update({"job_version": "20211113"})
+        data.update({"timeout": int(timeout)})
+        data.update({"type": runtime})
+        data.update({"inputs": json.dumps(inputs)})
+        data.update({"outputs": json.dumps(outputs)})
+        data.update({"labels": json.dumps(labels)})
+        self.phdy.put_data(table_name, data)
+
     def c9_create_init(self, path=None):
         if not path:
             path = self.job_path + "/__init__.py"
@@ -24,7 +54,9 @@ class PhRTPython3(PhRTBase):
             path = self.job_path
 
         config = PhYAMLConfig(path)
+        # self.put_items2dy(config)
         config.load_yaml()
+
         f_lines = self.phs3.open_object_by_lines(dv.TEMPLATE_BUCKET, dv.CLI_VERSION + dv.TEMPLATE_PHMAIN_FILE_PY)
         with open(path + "/phmain.py", "w") as file:
             s = []
@@ -61,34 +93,7 @@ class PhRTPython3(PhRTBase):
         logger.error(traceback.format_exc())
         print(traceback.format_exc())
         raise e
-        
-@click.command()
-@click.option('--owner')
-@click.option('--dag_name')
-@click.option('--run_id')
-@click.option('--job_full_name')
-@click.option('--job_id')
-@click.option('--job_args_name')
-def online_debug_execute(**kwargs):
-    try:
-        args = {"name": "$alfred_name"}
-        outputs = [$alfred_outputs]
-        
-        args.update(kwargs)
-        result = exec_before(**args)
 
-        args.update(result if isinstance(result, dict) else {})
-        result = execute(**args)
-
-        args.update(result if isinstance(result, dict) else {})
-        result = exec_after(outputs=outputs, **args)
-
-        return result
-    except Exception as e:
-        logger = phs3logger(kwargs["job_id"])
-        logger.error(traceback.format_exc())
-        print(traceback.format_exc())
-        raise e
 """
                                .replace('$alfred_outputs', ', '.join(['"'+output.key+'"' for output in config.spec.containers.outputs])) \
                                .replace('$alfred_name', config.metadata.name)
@@ -113,7 +118,7 @@ def online_debug_execute(**kwargs):
             file.write("""
     result_path_prefix = kwargs["result_path_prefix"]
     depends_path = kwargs["depends_path"]
-    
+
     logger.info(kwargs["a"])
     logger.info(kwargs["b"])
     logger.info(kwargs["c"])
