@@ -7,6 +7,7 @@ import base64
 
 from phcli.ph_aws.ph_s3 import PhS3
 from phcli.ph_aws.ph_sts import PhSts
+from phcli.ph_aws.PhDynamoDB import PhDynamoDB
 from phcli.ph_max_auto import define_value as dv
 from phcli.ph_max_auto.phcontext.ph_ide.ph_ide_c9 import PhIDEC9
 from phcli.ph_max_auto.phcontext.ph_ide.ph_ide_jupyter import PhIDEJupyter
@@ -31,6 +32,7 @@ class PhContextFacade(object):
             dv.ASSUME_ROLE_EXTERNAL_ID,
         )
         self.phs3 = PhS3(phsts=self.phsts)
+        self.phdy = PhDynamoDB(phsts=self.phsts)
         self.__dict__.update(kwargs)
         self.ide_table = {
             'c9': PhIDEC9,
